@@ -91,6 +91,8 @@ class NumbersTest(CoverageTest):
             n_missing_branches=3,
             n_partial_branches=1000,
         )
+        assert n.ratio_statements == (153, 200)
+        assert n.ratio_branches == (7, 10)
         assert n.ratio_covered == (160, 210)
 
 
